"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.datasphere.v1.project_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateProjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    LIMITS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a project in.
    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the project."""
    description: builtins.str
    """Description of the project."""
    @property
    def settings(self) -> yandex.cloud.datasphere.v1.project_pb2.Project.Settings:
        """Settings of the project."""

    @property
    def limits(self) -> yandex.cloud.datasphere.v1.project_pb2.Project.Limits:
        """Limits of the project."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        settings: yandex.cloud.datasphere.v1.project_pb2.Project.Settings | None = ...,
        limits: yandex.cloud.datasphere.v1.project_pb2.Project.Limits | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["limits", b"limits", "settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "limits", b"limits", "name", b"name", "settings", b"settings"]) -> None: ...

global___CreateProjectRequest = CreateProjectRequest

@typing.final
class CreateProjectMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project that is being created."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___CreateProjectMetadata = CreateProjectMetadata

@typing.final
class UpdateProjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    LIMITS_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the Project resource to update.
    To get the project ID use a [ProjectService.List] request.
    """
    name: builtins.str
    """Name of the project."""
    description: builtins.str
    """Description of the project."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Project resource are going to be updated."""

    @property
    def settings(self) -> yandex.cloud.datasphere.v1.project_pb2.Project.Settings:
        """Settings of the project."""

    @property
    def limits(self) -> yandex.cloud.datasphere.v1.project_pb2.Project.Limits:
        """Limits of the project."""

    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        settings: yandex.cloud.datasphere.v1.project_pb2.Project.Settings | None = ...,
        limits: yandex.cloud.datasphere.v1.project_pb2.Project.Limits | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["limits", b"limits", "settings", b"settings", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "limits", b"limits", "name", b"name", "project_id", b"project_id", "settings", b"settings", "update_mask", b"update_mask"]) -> None: ...

global___UpdateProjectRequest = UpdateProjectRequest

@typing.final
class UpdateProjectMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project that is being updated."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___UpdateProjectMetadata = UpdateProjectMetadata

@typing.final
class DeleteProjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the Project resource to delete.
    To get the project ID use a [ProjectService.List] request.
    """
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___DeleteProjectRequest = DeleteProjectRequest

@typing.final
class DeleteProjectMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project that is being deleted."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___DeleteProjectMetadata = DeleteProjectMetadata

@typing.final
class OpenProjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the Project resource to open.
    To get the project ID use a [ProjectService.List] request.
    """
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___OpenProjectRequest = OpenProjectRequest

@typing.final
class OpenProjectMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project that is being opened."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___OpenProjectMetadata = OpenProjectMetadata

@typing.final
class OpenProjectResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_URL_FIELD_NUMBER: builtins.int
    SESSION_TOKEN_FIELD_NUMBER: builtins.int
    project_url: builtins.str
    """URL of the project that is being opened.
    Make GET request to [project_url] with sessionToken query parameter equals to [session_token]
    or POST request to [project_url] with sessionToken body parameter equals to [session_token]
    to fetch Datasphere web interface.
    """
    session_token: builtins.str
    """Session token of the project that is being opened."""
    def __init__(
        self,
        *,
        project_url: builtins.str = ...,
        session_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_url", b"project_url", "session_token", b"session_token"]) -> None: ...

global___OpenProjectResponse = OpenProjectResponse

@typing.final
class GetProjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the Project resource to return.
    To get the project ID use a [ProjectService.List] request.
    """
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___GetProjectRequest = GetProjectRequest

@typing.final
class ListProjectsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list projects in.
    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListProjectsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListProjectsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListProjectsRequest = ListProjectsRequest

@typing.final
class ListProjectsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListProjectsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListProjectsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def projects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datasphere.v1.project_pb2.Project]:
        """List of Project resources."""

    def __init__(
        self,
        *,
        projects: collections.abc.Iterable[yandex.cloud.datasphere.v1.project_pb2.Project] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "projects", b"projects"]) -> None: ...

global___ListProjectsResponse = ListProjectsResponse

@typing.final
class GetUnitBalanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project to return the unit balance for."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___GetUnitBalanceRequest = GetUnitBalanceRequest

@typing.final
class GetUnitBalanceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNIT_BALANCE_FIELD_NUMBER: builtins.int
    @property
    def unit_balance(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of units available to the project."""

    def __init__(
        self,
        *,
        unit_balance: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["unit_balance", b"unit_balance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["unit_balance", b"unit_balance"]) -> None: ...

global___GetUnitBalanceResponse = GetUnitBalanceResponse

@typing.final
class SetUnitBalanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    UNIT_BALANCE_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project to set the unit balance for."""
    @property
    def unit_balance(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of units available to the project."""

    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        unit_balance: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["unit_balance", b"unit_balance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id", "unit_balance", b"unit_balance"]) -> None: ...

global___SetUnitBalanceRequest = SetUnitBalanceRequest

@typing.final
class ProjectExecutionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    NOTEBOOK_ID_FIELD_NUMBER: builtins.int
    CELL_ID_FIELD_NUMBER: builtins.int
    INPUT_VARIABLES_FIELD_NUMBER: builtins.int
    OUTPUT_VARIABLE_NAMES_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project to execute notebook/cell in."""
    notebook_id: builtins.str
    """ID of the notebook to execute."""
    cell_id: builtins.str
    """ID of the cell to execute."""
    @property
    def input_variables(self) -> google.protobuf.struct_pb2.Struct:
        """Values of input variables."""

    @property
    def output_variable_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Names of output variables."""

    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        notebook_id: builtins.str = ...,
        cell_id: builtins.str = ...,
        input_variables: google.protobuf.struct_pb2.Struct | None = ...,
        output_variable_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cell_id", b"cell_id", "input_variables", b"input_variables", "notebook_id", b"notebook_id", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cell_id", b"cell_id", "input_variables", b"input_variables", "notebook_id", b"notebook_id", "output_variable_names", b"output_variable_names", "project_id", b"project_id", "target", b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["target", b"target"]) -> typing.Literal["notebook_id", "cell_id"] | None: ...

global___ProjectExecutionRequest = ProjectExecutionRequest

@typing.final
class ProjectExecutionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    NOTEBOOK_ID_FIELD_NUMBER: builtins.int
    CELL_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project in which notebook is being executed."""
    notebook_id: builtins.str
    """ID of the notebook that is being executed"""
    cell_id: builtins.str
    """ID of the cell that is being executed"""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        notebook_id: builtins.str = ...,
        cell_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cell_id", b"cell_id", "notebook_id", b"notebook_id", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cell_id", b"cell_id", "notebook_id", b"notebook_id", "project_id", b"project_id", "target", b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["target", b"target"]) -> typing.Literal["notebook_id", "cell_id"] | None: ...

global___ProjectExecutionMetadata = ProjectExecutionMetadata

@typing.final
class ProjectExecutionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHECKPOINT_ID_FIELD_NUMBER: builtins.int
    OUTPUT_VARIABLES_FIELD_NUMBER: builtins.int
    checkpoint_id: builtins.str
    """ID of the checkpoint resulting from the execution."""
    @property
    def output_variables(self) -> google.protobuf.struct_pb2.Struct:
        """Values of output variables resulting from the execution."""

    def __init__(
        self,
        *,
        checkpoint_id: builtins.str = ...,
        output_variables: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["output_variables", b"output_variables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["checkpoint_id", b"checkpoint_id", "output_variables", b"output_variables"]) -> None: ...

global___ProjectExecutionResponse = ProjectExecutionResponse

@typing.final
class CellOutputsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    CELL_ID_FIELD_NUMBER: builtins.int
    CHECKPOINT_ID_FIELD_NUMBER: builtins.int
    START_AT_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project to return cell outputs for."""
    cell_id: builtins.str
    """ID of the cell to return outputs for."""
    checkpoint_id: builtins.str
    """ID of the checkpoint to return cell outputs for."""
    @property
    def start_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp from which to return outputs."""

    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        cell_id: builtins.str = ...,
        checkpoint_id: builtins.str = ...,
        start_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["start_at", b"start_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cell_id", b"cell_id", "checkpoint_id", b"checkpoint_id", "project_id", b"project_id", "start_at", b"start_at"]) -> None: ...

global___CellOutputsRequest = CellOutputsRequest

@typing.final
class CellOutputsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of outputs."""

    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["outputs", b"outputs"]) -> None: ...

global___CellOutputsResponse = CellOutputsResponse

@typing.final
class GetStateVariablesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    NOTEBOOK_ID_FIELD_NUMBER: builtins.int
    VARIABLE_NAMES_FIELD_NUMBER: builtins.int
    CHECKPOINT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project, for which to return state variables."""
    notebook_id: builtins.str
    """ID of the notebook, for which to return state variables."""
    checkpoint_id: builtins.str
    """ID of the checkpoint, for which to return state variables."""
    @property
    def variable_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Names of variables to return."""

    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        notebook_id: builtins.str = ...,
        variable_names: collections.abc.Iterable[builtins.str] | None = ...,
        checkpoint_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["checkpoint_id", b"checkpoint_id", "notebook_id", b"notebook_id", "project_id", b"project_id", "variable_names", b"variable_names"]) -> None: ...

global___GetStateVariablesRequest = GetStateVariablesRequest

@typing.final
class GetStateVariablesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VARIABLES_FIELD_NUMBER: builtins.int
    @property
    def variables(self) -> google.protobuf.struct_pb2.Struct:
        """Values of the specified variables."""

    def __init__(
        self,
        *,
        variables: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["variables", b"variables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["variables", b"variables"]) -> None: ...

global___GetStateVariablesResponse = GetStateVariablesResponse

@typing.final
class GetNotebookMetadataRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    NOTEBOOK_PATH_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project, for which to return notebook metadata."""
    notebook_path: builtins.str
    """Path of the notebook to get metadata."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        notebook_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["notebook_path", b"notebook_path", "project_id", b"project_id"]) -> None: ...

global___GetNotebookMetadataRequest = GetNotebookMetadataRequest

@typing.final
class GetNotebookMetadataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTEBOOK_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    MODIFIED_AT_FIELD_NUMBER: builtins.int
    CONTENT_LENGTH_FIELD_NUMBER: builtins.int
    CELL_IDS_FIELD_NUMBER: builtins.int
    notebook_id: builtins.str
    """ID of the specified notebook."""
    content_length: builtins.int
    """Content length of the specified notebook."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time the notebook was created."""

    @property
    def modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time the notebook was modified last time."""

    @property
    def cell_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Cell ids of the specified notebook."""

    def __init__(
        self,
        *,
        notebook_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        content_length: builtins.int = ...,
        cell_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "modified_at", b"modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cell_ids", b"cell_ids", "content_length", b"content_length", "created_at", b"created_at", "modified_at", b"modified_at", "notebook_id", b"notebook_id"]) -> None: ...

global___GetNotebookMetadataResponse = GetNotebookMetadataResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/kafka/v1/user_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.kafka.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/mdb/kafka/v1/user_service.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a$yandex/cloud/mdb/kafka/v1/user.proto\"d\n\x0eGetUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04\x31-63\"r\n\x10ListUsersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\\\n\x11ListUsersResponse\x12.\n\x05users\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.mdb.kafka.v1.User\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"s\n\x11\x43reateUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\tuser_spec\x18\x02 \x01(\x0b\x32#.yandex.cloud.mdb.kafka.v1.UserSpecB\x04\xe8\xc7\x31\x01\";\n\x12\x43reateUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"\xf1\x01\n\x11UpdateUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04\x31-63\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1b\n\x08password\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05\x38-128\x12:\n\x0bpermissions\x18\x05 \x03(\x0b\x32%.yandex.cloud.mdb.kafka.v1.Permission\";\n\x12UpdateUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"g\n\x11\x44\x65leteUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04\x31-63\";\n\x12\x44\x65leteUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"\xb1\x01\n\x1aGrantUserPermissionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04\x31-63\x12?\n\npermission\x18\x03 \x01(\x0b\x32%.yandex.cloud.mdb.kafka.v1.PermissionB\x04\xe8\xc7\x31\x01\"D\n\x1bGrantUserPermissionMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"\xb2\x01\n\x1bRevokeUserPermissionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04\x31-63\x12?\n\npermission\x18\x03 \x01(\x0b\x32%.yandex.cloud.mdb.kafka.v1.PermissionB\x04\xe8\xc7\x31\x01\"E\n\x1cRevokeUserPermissionMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t2\xdb\n\n\x0bUserService\x12\x94\x01\n\x03Get\x12).yandex.cloud.mdb.kafka.v1.GetUserRequest\x1a\x1f.yandex.cloud.mdb.kafka.v1.User\"A\x82\xd3\xe4\x93\x02;\x12\x39/managed-kafka/v1/clusters/{cluster_id}/users/{user_name}\x12\x98\x01\n\x04List\x12+.yandex.cloud.mdb.kafka.v1.ListUsersRequest\x1a,.yandex.cloud.mdb.kafka.v1.ListUsersResponse\"5\x82\xd3\xe4\x93\x02/\x12-/managed-kafka/v1/clusters/{cluster_id}/users\x12\xb1\x01\n\x06\x43reate\x12,.yandex.cloud.mdb.kafka.v1.CreateUserRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*\x1a\n\x12\x43reateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02\x32\"-/managed-kafka/v1/clusters/{cluster_id}/users:\x01*\x12\xbd\x01\n\x06Update\x12,.yandex.cloud.mdb.kafka.v1.UpdateUserRequest\x1a!.yandex.cloud.operation.Operation\"b\xb2\xd2*\x1a\n\x12UpdateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02>29/managed-kafka/v1/clusters/{cluster_id}/users/{user_name}:\x01*\x12\xcb\x01\n\x06\x44\x65lete\x12,.yandex.cloud.mdb.kafka.v1.DeleteUserRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*+\n\x12\x44\x65leteUserMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02;*9/managed-kafka/v1/clusters/{cluster_id}/users/{user_name}\x12\xe8\x01\n\x0fGrantPermission\x12\x35.yandex.cloud.mdb.kafka.v1.GrantUserPermissionRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*#\n\x1bGrantUserPermissionMetadata\x12\x04User\x82\xd3\xe4\x93\x02N\"I/managed-kafka/v1/clusters/{cluster_id}/users/{user_name}:grantPermission:\x01*\x12\xec\x01\n\x10RevokePermission\x12\x36.yandex.cloud.mdb.kafka.v1.RevokeUserPermissionRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*$\n\x1cRevokeUserPermissionMetadata\x12\x04User\x82\xd3\xe4\x93\x02O\"J/managed-kafka/v1/clusters/{cluster_id}/users/{user_name}:revokePermission:\x01*Bd\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.kafka.v1.user_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka'
  _GETUSERREQUEST.fields_by_name['cluster_id']._options = None
  _GETUSERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETUSERREQUEST.fields_by_name['user_name']._options = None
  _GETUSERREQUEST.fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\0041-63'
  _LISTUSERSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTUSERSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTUSERSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTUSERSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEUSERREQUEST.fields_by_name['cluster_id']._options = None
  _CREATEUSERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEUSERREQUEST.fields_by_name['user_spec']._options = None
  _CREATEUSERREQUEST.fields_by_name['user_spec']._serialized_options = b'\350\3071\001'
  _UPDATEUSERREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATEUSERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEUSERREQUEST.fields_by_name['user_name']._options = None
  _UPDATEUSERREQUEST.fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\0041-63'
  _UPDATEUSERREQUEST.fields_by_name['password']._options = None
  _UPDATEUSERREQUEST.fields_by_name['password']._serialized_options = b'\212\3101\0058-128'
  _DELETEUSERREQUEST.fields_by_name['cluster_id']._options = None
  _DELETEUSERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEUSERREQUEST.fields_by_name['user_name']._options = None
  _DELETEUSERREQUEST.fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\0041-63'
  _GRANTUSERPERMISSIONREQUEST.fields_by_name['cluster_id']._options = None
  _GRANTUSERPERMISSIONREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GRANTUSERPERMISSIONREQUEST.fields_by_name['user_name']._options = None
  _GRANTUSERPERMISSIONREQUEST.fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\0041-63'
  _GRANTUSERPERMISSIONREQUEST.fields_by_name['permission']._options = None
  _GRANTUSERPERMISSIONREQUEST.fields_by_name['permission']._serialized_options = b'\350\3071\001'
  _REVOKEUSERPERMISSIONREQUEST.fields_by_name['cluster_id']._options = None
  _REVOKEUSERPERMISSIONREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REVOKEUSERPERMISSIONREQUEST.fields_by_name['user_name']._options = None
  _REVOKEUSERPERMISSIONREQUEST.fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\0041-63'
  _REVOKEUSERPERMISSIONREQUEST.fields_by_name['permission']._options = None
  _REVOKEUSERPERMISSIONREQUEST.fields_by_name['permission']._serialized_options = b'\350\3071\001'
  _USERSERVICE.methods_by_name['Get']._options = None
  _USERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002;\0229/managed-kafka/v1/clusters/{cluster_id}/users/{user_name}'
  _USERSERVICE.methods_by_name['List']._options = None
  _USERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002/\022-/managed-kafka/v1/clusters/{cluster_id}/users'
  _USERSERVICE.methods_by_name['Create']._options = None
  _USERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\032\n\022CreateUserMetadata\022\004User\202\323\344\223\0022\"-/managed-kafka/v1/clusters/{cluster_id}/users:\001*'
  _USERSERVICE.methods_by_name['Update']._options = None
  _USERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\032\n\022UpdateUserMetadata\022\004User\202\323\344\223\002>29/managed-kafka/v1/clusters/{cluster_id}/users/{user_name}:\001*'
  _USERSERVICE.methods_by_name['Delete']._options = None
  _USERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*+\n\022DeleteUserMetadata\022\025google.protobuf.Empty\202\323\344\223\002;*9/managed-kafka/v1/clusters/{cluster_id}/users/{user_name}'
  _USERSERVICE.methods_by_name['GrantPermission']._options = None
  _USERSERVICE.methods_by_name['GrantPermission']._serialized_options = b'\262\322*#\n\033GrantUserPermissionMetadata\022\004User\202\323\344\223\002N\"I/managed-kafka/v1/clusters/{cluster_id}/users/{user_name}:grantPermission:\001*'
  _USERSERVICE.methods_by_name['RevokePermission']._options = None
  _USERSERVICE.methods_by_name['RevokePermission']._serialized_options = b'\262\322*$\n\034RevokeUserPermissionMetadata\022\004User\202\323\344\223\002O\"J/managed-kafka/v1/clusters/{cluster_id}/users/{user_name}:revokePermission:\001*'
  _globals['_GETUSERREQUEST']._serialized_start=282
  _globals['_GETUSERREQUEST']._serialized_end=382
  _globals['_LISTUSERSREQUEST']._serialized_start=384
  _globals['_LISTUSERSREQUEST']._serialized_end=498
  _globals['_LISTUSERSRESPONSE']._serialized_start=500
  _globals['_LISTUSERSRESPONSE']._serialized_end=592
  _globals['_CREATEUSERREQUEST']._serialized_start=594
  _globals['_CREATEUSERREQUEST']._serialized_end=709
  _globals['_CREATEUSERMETADATA']._serialized_start=711
  _globals['_CREATEUSERMETADATA']._serialized_end=770
  _globals['_UPDATEUSERREQUEST']._serialized_start=773
  _globals['_UPDATEUSERREQUEST']._serialized_end=1014
  _globals['_UPDATEUSERMETADATA']._serialized_start=1016
  _globals['_UPDATEUSERMETADATA']._serialized_end=1075
  _globals['_DELETEUSERREQUEST']._serialized_start=1077
  _globals['_DELETEUSERREQUEST']._serialized_end=1180
  _globals['_DELETEUSERMETADATA']._serialized_start=1182
  _globals['_DELETEUSERMETADATA']._serialized_end=1241
  _globals['_GRANTUSERPERMISSIONREQUEST']._serialized_start=1244
  _globals['_GRANTUSERPERMISSIONREQUEST']._serialized_end=1421
  _globals['_GRANTUSERPERMISSIONMETADATA']._serialized_start=1423
  _globals['_GRANTUSERPERMISSIONMETADATA']._serialized_end=1491
  _globals['_REVOKEUSERPERMISSIONREQUEST']._serialized_start=1494
  _globals['_REVOKEUSERPERMISSIONREQUEST']._serialized_end=1672
  _globals['_REVOKEUSERPERMISSIONMETADATA']._serialized_start=1674
  _globals['_REVOKEUSERPERMISSIONMETADATA']._serialized_end=1743
  _globals['_USERSERVICE']._serialized_start=1746
  _globals['_USERSERVICE']._serialized_end=3117
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.assistants.v1.threads.message_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateMessageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    THREAD_ID_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    thread_id: builtins.str
    @property
    def author(self) -> yandex.cloud.ai.assistants.v1.threads.message_pb2.Author: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def content(self) -> yandex.cloud.ai.assistants.v1.threads.message_pb2.MessageContent: ...
    def __init__(
        self,
        *,
        thread_id: builtins.str = ...,
        author: yandex.cloud.ai.assistants.v1.threads.message_pb2.Author | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        content: yandex.cloud.ai.assistants.v1.threads.message_pb2.MessageContent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["author", b"author", "content", b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "content", b"content", "labels", b"labels", "thread_id", b"thread_id"]) -> None: ...

global___CreateMessageRequest = CreateMessageRequest

@typing.final
class GetMessageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THREAD_ID_FIELD_NUMBER: builtins.int
    MESSAGE_ID_FIELD_NUMBER: builtins.int
    thread_id: builtins.str
    message_id: builtins.str
    def __init__(
        self,
        *,
        thread_id: builtins.str = ...,
        message_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["message_id", b"message_id", "thread_id", b"thread_id"]) -> None: ...

global___GetMessageRequest = GetMessageRequest

@typing.final
class ListMessagesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THREAD_ID_FIELD_NUMBER: builtins.int
    thread_id: builtins.str
    def __init__(
        self,
        *,
        thread_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["thread_id", b"thread_id"]) -> None: ...

global___ListMessagesRequest = ListMessagesRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.resourcemanager.v1.folder_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetFolderRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the Folder resource to return.
    To get the folder ID, use a [FolderService.List] request.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___GetFolderRequest = GetFolderRequest

@typing.final
class ListFoldersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    cloud_id: builtins.str
    """ID of the cloud to list folders in.
    To get the cloud ID, use a [yandex.cloud.resourcemanager.v1.CloudService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListFoldersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set [page_token]
    to the [ListFoldersResponse.next_page_token]
    returned by a previous list request to get the next page of results.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on the [Folder.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        cloud_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListFoldersRequest = ListFoldersRequest

@typing.final
class ListFoldersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListFoldersRequest.page_size], use
    the [next_page_token] as the value
    for the [ListFoldersRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def folders(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.resourcemanager.v1.folder_pb2.Folder]:
        """List of Folder resources."""

    def __init__(
        self,
        *,
        folders: collections.abc.Iterable[yandex.cloud.resourcemanager.v1.folder_pb2.Folder] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folders", b"folders", "next_page_token", b"next_page_token"]) -> None: ...

global___ListFoldersResponse = ListFoldersResponse

@typing.final
class CreateFolderRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLOUD_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    cloud_id: builtins.str
    """ID of the cloud to create a folder in.
    To get the cloud ID, use a [yandex.cloud.resourcemanager.v1.CloudService.List] request.
    """
    name: builtins.str
    """Name of the folder.
    The name must be unique within the cloud.
    """
    description: builtins.str
    """Description of the folder."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    def __init__(
        self,
        *,
        cloud_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "description", b"description", "labels", b"labels", "name", b"name"]) -> None: ...

global___CreateFolderRequest = CreateFolderRequest

@typing.final
class CreateFolderMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that is being created."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___CreateFolderMetadata = CreateFolderMetadata

@typing.final
class UpdateFolderRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the Folder resource to update.
    To get the folder ID, use a [FolderService.List] request.
    """
    name: builtins.str
    """Name of the folder.
    The name must be unique within the cloud.
    """
    description: builtins.str
    """Description of the folder."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Folder resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateFolderRequest = UpdateFolderRequest

@typing.final
class UpdateFolderMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the Folder resource that is being updated."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___UpdateFolderMetadata = UpdateFolderMetadata

@typing.final
class DeleteFolderRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    DELETE_AFTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to delete.
    To get the folder ID, use a [FolderService.List] request.
    """
    @property
    def delete_after(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The timestamp after which the process of deleting the folder should begin.
        Until this timestamp, the folder goes into the [Folder.Status.PENDING_DELETION] state and all resources in this
        folder are stopped. In this state, it is possible to cancel the delete operation without any loss.
        After this timestamp, the status of the folder will become [Folder.Status.DELETING] and the process of deleting
        all the resources  of the folder will be started. If [delete_after] is not specified it will be
        (now + 24 hours). To initiate an immediate deletion [delete_after] must be <= now.
        """

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        delete_after: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["delete_after", b"delete_after"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["delete_after", b"delete_after", "folder_id", b"folder_id"]) -> None: ...

global___DeleteFolderRequest = DeleteFolderRequest

@typing.final
class DeleteFolderMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    DELETE_AFTER_FIELD_NUMBER: builtins.int
    CANCELLED_BY_FIELD_NUMBER: builtins.int
    CANCELLED_AT_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder that is being deleted."""
    cancelled_by: builtins.str
    """Information about operation cancellation"""
    @property
    def delete_after(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The timestamp after which the process of deleting the folder should begin."""

    @property
    def cancelled_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        delete_after: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        cancelled_by: builtins.str = ...,
        cancelled_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cancelled_at", b"cancelled_at", "delete_after", b"delete_after"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cancelled_at", b"cancelled_at", "cancelled_by", b"cancelled_by", "delete_after", b"delete_after", "folder_id", b"folder_id"]) -> None: ...

global___DeleteFolderMetadata = DeleteFolderMetadata

@typing.final
class ListFolderOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the Folder resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListFolderOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set [page_token]
    to the [ListFolderOperationsResponse.next_page_token]
    returned by a previous list request to get the next page of results.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListFolderOperationsRequest = ListFolderOperationsRequest

@typing.final
class ListFolderOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListFolderOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListFolderOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified folder."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListFolderOperationsResponse = ListFolderOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.video.v1.stream_line_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetStreamLineRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the line."""
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___GetStreamLineRequest = GetStreamLineRequest

@typing.final
class ListStreamLinesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    page_size: builtins.int
    """The maximum number of the results per page to return. Default value: 100."""
    page_token: builtins.str
    """Page token for getting the next page of the result."""
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    Possible fields: ["id", "title", "createdAt", "updatedAt"]
    Both snake_case and camelCase are supported for fields.
    """
    filter: builtins.str
    """Filter expression that filters resources listed in the response.
    Expressions are composed of terms connected by logic operators.
    Value in quotes: `'` or `"`
    Example: "key1='value' AND key2='value'"
    Supported operators: ["AND"].
    Supported fields: ["title"]
    Both snake_case and camelCase are supported for fields.
    """
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListStreamLinesRequest = ListStreamLinesRequest

@typing.final
class ListStreamLinesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page."""
    @property
    def stream_lines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.stream_line_pb2.StreamLine]:
        """List of lines for channel."""

    def __init__(
        self,
        *,
        stream_lines: collections.abc.Iterable[yandex.cloud.video.v1.stream_line_pb2.StreamLine] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "stream_lines", b"stream_lines"]) -> None: ...

global___ListStreamLinesResponse = ListStreamLinesResponse

@typing.final
class CreateStreamLineRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RTMP_PUSH_FIELD_NUMBER: builtins.int
    SRT_PUSH_FIELD_NUMBER: builtins.int
    RTMP_PULL_FIELD_NUMBER: builtins.int
    SRT_PULL_FIELD_NUMBER: builtins.int
    TCP_PULL_FIELD_NUMBER: builtins.int
    RTSP_PULL_FIELD_NUMBER: builtins.int
    MANUAL_LINE_FIELD_NUMBER: builtins.int
    AUTO_LINE_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    title: builtins.str
    """Line title."""
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels as `` key:value `` pairs. Maximum 64 per resource."""

    @property
    def rtmp_push(self) -> global___RTMPPushParams:
        """RTMP push input type."""

    @property
    def srt_push(self) -> global___SRTPushParams:
        """SRT push input type."""

    @property
    def rtmp_pull(self) -> global___RTMPPullParams:
        """RTMP pull input type."""

    @property
    def srt_pull(self) -> global___SRTPullParams:
        """SRT pull input type."""

    @property
    def tcp_pull(self) -> global___TCPPullParams:
        """TCP pull input type."""

    @property
    def rtsp_pull(self) -> global___RTSPPullParams:
        """RTSP pull input type."""

    @property
    def manual_line(self) -> global___ManualLineParams:
        """Manual control of stream."""

    @property
    def auto_line(self) -> global___AutoLineParams:
        """Automatic control of stream."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        title: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        rtmp_push: global___RTMPPushParams | None = ...,
        srt_push: global___SRTPushParams | None = ...,
        rtmp_pull: global___RTMPPullParams | None = ...,
        srt_pull: global___SRTPullParams | None = ...,
        tcp_pull: global___TCPPullParams | None = ...,
        rtsp_pull: global___RTSPPullParams | None = ...,
        manual_line: global___ManualLineParams | None = ...,
        auto_line: global___AutoLineParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auto_line", b"auto_line", "input_params", b"input_params", "line_type_params", b"line_type_params", "manual_line", b"manual_line", "rtmp_pull", b"rtmp_pull", "rtmp_push", b"rtmp_push", "rtsp_pull", b"rtsp_pull", "srt_pull", b"srt_pull", "srt_push", b"srt_push", "tcp_pull", b"tcp_pull"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_line", b"auto_line", "channel_id", b"channel_id", "input_params", b"input_params", "labels", b"labels", "line_type_params", b"line_type_params", "manual_line", b"manual_line", "rtmp_pull", b"rtmp_pull", "rtmp_push", b"rtmp_push", "rtsp_pull", b"rtsp_pull", "srt_pull", b"srt_pull", "srt_push", b"srt_push", "tcp_pull", b"tcp_pull", "thumbnail_id", b"thumbnail_id", "title", b"title"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["input_params", b"input_params"]) -> typing.Literal["rtmp_push", "srt_push", "rtmp_pull", "srt_pull", "tcp_pull", "rtsp_pull"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["line_type_params", b"line_type_params"]) -> typing.Literal["manual_line", "auto_line"] | None: ...

global___CreateStreamLineRequest = CreateStreamLineRequest

@typing.final
class CreateStreamLineMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the line."""
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___CreateStreamLineMetadata = CreateStreamLineMetadata

@typing.final
class UpdateStreamLineRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RTMP_PUSH_FIELD_NUMBER: builtins.int
    SRT_PUSH_FIELD_NUMBER: builtins.int
    RTMP_PULL_FIELD_NUMBER: builtins.int
    SRT_PULL_FIELD_NUMBER: builtins.int
    TCP_PULL_FIELD_NUMBER: builtins.int
    RTSP_PULL_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the line."""
    title: builtins.str
    """Line title."""
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the line are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels as `` key:value `` pairs. Maximum 64 per resource."""

    @property
    def rtmp_push(self) -> global___RTMPPushParams:
        """RTMP push input type."""

    @property
    def srt_push(self) -> global___SRTPushParams:
        """SRT push input type."""

    @property
    def rtmp_pull(self) -> global___RTMPPullParams:
        """RTMP pull input type."""

    @property
    def srt_pull(self) -> global___SRTPullParams:
        """SRT pull input type."""

    @property
    def tcp_pull(self) -> global___TCPPullParams:
        """TCP pull input type."""

    @property
    def rtsp_pull(self) -> global___RTSPPullParams:
        """RTSP pull input type."""

    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        title: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        rtmp_push: global___RTMPPushParams | None = ...,
        srt_push: global___SRTPushParams | None = ...,
        rtmp_pull: global___RTMPPullParams | None = ...,
        srt_pull: global___SRTPullParams | None = ...,
        tcp_pull: global___TCPPullParams | None = ...,
        rtsp_pull: global___RTSPPullParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["field_mask", b"field_mask", "input_params", b"input_params", "rtmp_pull", b"rtmp_pull", "rtmp_push", b"rtmp_push", "rtsp_pull", b"rtsp_pull", "srt_pull", b"srt_pull", "srt_push", b"srt_push", "tcp_pull", b"tcp_pull"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["field_mask", b"field_mask", "input_params", b"input_params", "labels", b"labels", "rtmp_pull", b"rtmp_pull", "rtmp_push", b"rtmp_push", "rtsp_pull", b"rtsp_pull", "srt_pull", b"srt_pull", "srt_push", b"srt_push", "stream_line_id", b"stream_line_id", "tcp_pull", b"tcp_pull", "thumbnail_id", b"thumbnail_id", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["input_params", b"input_params"]) -> typing.Literal["rtmp_push", "srt_push", "rtmp_pull", "srt_pull", "tcp_pull", "rtsp_pull"] | None: ...

global___UpdateStreamLineRequest = UpdateStreamLineRequest

@typing.final
class UpdateStreamLineMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the line."""
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___UpdateStreamLineMetadata = UpdateStreamLineMetadata

@typing.final
class DeleteStreamLineRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the line."""
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___DeleteStreamLineRequest = DeleteStreamLineRequest

@typing.final
class DeleteStreamLineMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the line."""
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___DeleteStreamLineMetadata = DeleteStreamLineMetadata

@typing.final
class PerformLineActionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    ACTIVATE_FIELD_NUMBER: builtins.int
    DEACTIVATE_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the line."""
    @property
    def activate(self) -> global___ActivateAction: ...
    @property
    def deactivate(self) -> global___DeactivateAction: ...
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
        activate: global___ActivateAction | None = ...,
        deactivate: global___DeactivateAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "activate", b"activate", "deactivate", b"deactivate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "activate", b"activate", "deactivate", b"deactivate", "stream_line_id", b"stream_line_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["activate", "deactivate"] | None: ...

global___PerformLineActionRequest = PerformLineActionRequest

@typing.final
class PerformLineActionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the line."""
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___PerformLineActionMetadata = PerformLineActionMetadata

@typing.final
class RTMPPushParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RTMPPushParams = RTMPPushParams

@typing.final
class SRTPushParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SRTPushParams = SRTPushParams

@typing.final
class RTMPPullParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """URL of a RTMP streaming server."""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

global___RTMPPullParams = RTMPPullParams

@typing.final
class SRTPullParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """URL of a SRT streaming server."""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

global___SRTPullParams = SRTPullParams

@typing.final
class TCPPullParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """URL of a TCP streaming server."""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

global___TCPPullParams = TCPPullParams

@typing.final
class RTSPPullParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """URL of a RTSP streaming server."""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

global___RTSPPullParams = RTSPPullParams

@typing.final
class ManualLineParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ManualLineParams = ManualLineParams

@typing.final
class AutoLineParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AutoLineParams = AutoLineParams

@typing.final
class ActivateAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ActivateAction = ActivateAction

@typing.final
class DeactivateAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeactivateAction = DeactivateAction

@typing.final
class GetStreamKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the line."""
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___GetStreamKeyRequest = GetStreamKeyRequest

@typing.final
class UpdateStreamKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the line."""
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___UpdateStreamKeyRequest = UpdateStreamKeyRequest

@typing.final
class UpdateStreamKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_LINE_ID_FIELD_NUMBER: builtins.int
    stream_line_id: builtins.str
    """ID of the line."""
    def __init__(
        self,
        *,
        stream_line_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["stream_line_id", b"stream_line_id"]) -> None: ...

global___UpdateStreamKeyMetadata = UpdateStreamKeyMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Dataset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_BY_ID_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    SIZE_GB_FIELD_NUMBER: builtins.int
    ZONE_IDS_FIELD_NUMBER: builtins.int
    MOUNT_PATH_FIELD_NUMBER: builtins.int
    DATA_CAPSULE_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the dataset."""
    project_id: builtins.str
    """ID of the project."""
    name: builtins.str
    """Name of the dataset."""
    description: builtins.str
    """Description of the dataset."""
    created_by_id: builtins.str
    """ID of the user who created the dataset."""
    code: builtins.str
    """Code used to create dataset."""
    size_gb: builtins.int
    """Size of the dataset, Gb."""
    mount_path: builtins.str
    """Dataset mount path."""
    data_capsule_id: builtins.str
    """ID of the data capsule object, storing information about dataset storage."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time the dataset was created."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels of the dataset."""

    @property
    def zone_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Zone IDs where dataset is available."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        project_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_by_id: builtins.str = ...,
        code: builtins.str = ...,
        size_gb: builtins.int = ...,
        zone_ids: collections.abc.Iterable[builtins.str] | None = ...,
        mount_path: builtins.str = ...,
        data_capsule_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "created_at", b"created_at", "created_by_id", b"created_by_id", "data_capsule_id", b"data_capsule_id", "description", b"description", "id", b"id", "labels", b"labels", "mount_path", b"mount_path", "name", b"name", "project_id", b"project_id", "size_gb", b"size_gb", "zone_ids", b"zone_ids"]) -> None: ...

global___Dataset = Dataset

@typing.final
class DatasetStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class StatusActive(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class StatusInactive(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class StatusError(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ERROR_FIELD_NUMBER: builtins.int
        error: builtins.str
        """Text of the error."""
        def __init__(
            self,
            *,
            error: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["error", b"error"]) -> None: ...

    STATUS_ACTIVE_FIELD_NUMBER: builtins.int
    STATUS_INACTIVE_FIELD_NUMBER: builtins.int
    STATUS_ERROR_FIELD_NUMBER: builtins.int
    @property
    def status_active(self) -> global___DatasetStatus.StatusActive:
        """Dataset is activated."""

    @property
    def status_inactive(self) -> global___DatasetStatus.StatusInactive:
        """Dataset is inactive."""

    @property
    def status_error(self) -> global___DatasetStatus.StatusError:
        """Error while activating dataset."""

    def __init__(
        self,
        *,
        status_active: global___DatasetStatus.StatusActive | None = ...,
        status_inactive: global___DatasetStatus.StatusInactive | None = ...,
        status_error: global___DatasetStatus.StatusError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["status", b"status", "status_active", b"status_active", "status_error", b"status_error", "status_inactive", b"status_inactive"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["status", b"status", "status_active", b"status_active", "status_error", b"status_error", "status_inactive", b"status_inactive"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["status", b"status"]) -> typing.Literal["status_active", "status_inactive", "status_error"] | None: ...

global___DatasetStatus = DatasetStatus



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/sqlserver/v1/database_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.mdb.sqlserver.v1 import database_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_database__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/mdb/sqlserver/v1/database_service.proto\x12\x1dyandex.cloud.mdb.sqlserver.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/api/operation.proto\x1a,yandex/cloud/mdb/sqlserver/v1/database.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"m\n\x12GetDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"v\n\x14ListDatabasesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x15ListDatabasesResponse\x12:\n\tdatabases\x18\x01 \x03(\x0b\x32\'.yandex.cloud.mdb.sqlserver.v1.Database\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x83\x01\n\x15\x43reateDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12H\n\rdatabase_spec\x18\x02 \x01(\x0b\x32+.yandex.cloud.mdb.sqlserver.v1.DatabaseSpecB\x04\xe8\xc7\x31\x01\"C\n\x16\x43reateDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"p\n\x15\x44\x65leteDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"C\n\x16\x44\x65leteDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"\xc3\x01\n\x16RestoreDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rfrom_database\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tbackup_id\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01J\x04\x08\x05\x10\x06\"\x86\x01\n\x17RestoreDatabaseMetadata\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rfrom_database\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tbackup_id\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\"\x9b\x01\n\x1bImportDatabaseBackupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\ts3_bucket\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07s3_path\x18\x04 \x01(\t\x12\x13\n\x05\x66iles\x18\x05 \x03(\tB\x04\xe8\xc7\x31\x01\"\x7f\n\x1cImportDatabaseBackupMetadata\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\ts3_bucket\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07s3_path\x18\x04 \x01(\t\"\x96\x01\n\x1b\x45xportDatabaseBackupRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\ts3_bucket\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07s3_path\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x05 \x01(\t\"\x7f\n\x1c\x45xportDatabaseBackupMetadata\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rdatabase_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\ts3_bucket\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07s3_path\x18\x04 \x01(\t2\xbe\x0b\n\x0f\x44\x61tabaseService\x12\xac\x01\n\x03Get\x12\x31.yandex.cloud.mdb.sqlserver.v1.GetDatabaseRequest\x1a\'.yandex.cloud.mdb.sqlserver.v1.Database\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}\x12\xac\x01\n\x04List\x12\x33.yandex.cloud.mdb.sqlserver.v1.ListDatabasesRequest\x1a\x34.yandex.cloud.mdb.sqlserver.v1.ListDatabasesResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/mdb/sqlserver/v1/clusters/{cluster_id}/databases\x12\xc5\x01\n\x06\x43reate\x12\x34.yandex.cloud.mdb.sqlserver.v1.CreateDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"b\xb2\xd2*\"\n\x16\x43reateDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02\x36\"1/mdb/sqlserver/v1/clusters/{cluster_id}/databases:\x01*\x12\xd0\x01\n\x07Restore\x12\x35.yandex.cloud.mdb.sqlserver.v1.RestoreDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2*#\n\x17RestoreDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02>\"9/mdb/sqlserver/v1/clusters/{cluster_id}/databases:restore:\x01*\x12\xde\x01\n\x0cImportBackup\x12:.yandex.cloud.mdb.sqlserver.v1.ImportDatabaseBackupRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*(\n\x1cImportDatabaseBackupMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02=\"8/mdb/sqlserver/v1/clusters/{cluster_id}/databases:import:\x01*\x12\xee\x01\n\x0c\x45xportBackup\x12:.yandex.cloud.mdb.sqlserver.v1.ExportDatabaseBackupRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*(\n\x1c\x45xportDatabaseBackupMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02M\"H/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}:export:\x01*\x12\xdf\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.mdb.sqlserver.v1.DeleteDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"|\xb2\xd2*/\n\x16\x44\x65leteDatabaseMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x43*A/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}Bv\n!yandex.cloud.api.mdb.sqlserver.v1B\x04PSDSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.sqlserver.v1.database_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.mdb.sqlserver.v1B\004PSDSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserver'
  _GETDATABASEREQUEST.fields_by_name['cluster_id']._options = None
  _GETDATABASEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETDATABASEREQUEST.fields_by_name['database_name']._options = None
  _GETDATABASEREQUEST.fields_by_name['database_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _LISTDATABASESREQUEST.fields_by_name['cluster_id']._options = None
  _LISTDATABASESREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTDATABASESREQUEST.fields_by_name['page_size']._options = None
  _LISTDATABASESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTDATABASESREQUEST.fields_by_name['page_token']._options = None
  _LISTDATABASESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEDATABASEREQUEST.fields_by_name['cluster_id']._options = None
  _CREATEDATABASEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEDATABASEREQUEST.fields_by_name['database_spec']._options = None
  _CREATEDATABASEREQUEST.fields_by_name['database_spec']._serialized_options = b'\350\3071\001'
  _DELETEDATABASEREQUEST.fields_by_name['cluster_id']._options = None
  _DELETEDATABASEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEDATABASEREQUEST.fields_by_name['database_name']._options = None
  _DELETEDATABASEREQUEST.fields_by_name['database_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _RESTOREDATABASEREQUEST.fields_by_name['cluster_id']._options = None
  _RESTOREDATABASEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESTOREDATABASEREQUEST.fields_by_name['database_name']._options = None
  _RESTOREDATABASEREQUEST.fields_by_name['database_name']._serialized_options = b'\350\3071\001'
  _RESTOREDATABASEREQUEST.fields_by_name['from_database']._options = None
  _RESTOREDATABASEREQUEST.fields_by_name['from_database']._serialized_options = b'\350\3071\001'
  _RESTOREDATABASEREQUEST.fields_by_name['backup_id']._options = None
  _RESTOREDATABASEREQUEST.fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _RESTOREDATABASEREQUEST.fields_by_name['time']._options = None
  _RESTOREDATABASEREQUEST.fields_by_name['time']._serialized_options = b'\350\3071\001'
  _RESTOREDATABASEMETADATA.fields_by_name['cluster_id']._options = None
  _RESTOREDATABASEMETADATA.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _RESTOREDATABASEMETADATA.fields_by_name['database_name']._options = None
  _RESTOREDATABASEMETADATA.fields_by_name['database_name']._serialized_options = b'\350\3071\001'
  _RESTOREDATABASEMETADATA.fields_by_name['from_database']._options = None
  _RESTOREDATABASEMETADATA.fields_by_name['from_database']._serialized_options = b'\350\3071\001'
  _RESTOREDATABASEMETADATA.fields_by_name['backup_id']._options = None
  _RESTOREDATABASEMETADATA.fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['cluster_id']._options = None
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['database_name']._options = None
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['database_name']._serialized_options = b'\350\3071\001'
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['s3_bucket']._options = None
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['s3_bucket']._serialized_options = b'\350\3071\001'
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['files']._options = None
  _IMPORTDATABASEBACKUPREQUEST.fields_by_name['files']._serialized_options = b'\350\3071\001'
  _IMPORTDATABASEBACKUPMETADATA.fields_by_name['cluster_id']._options = None
  _IMPORTDATABASEBACKUPMETADATA.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _IMPORTDATABASEBACKUPMETADATA.fields_by_name['database_name']._options = None
  _IMPORTDATABASEBACKUPMETADATA.fields_by_name['database_name']._serialized_options = b'\350\3071\001'
  _IMPORTDATABASEBACKUPMETADATA.fields_by_name['s3_bucket']._options = None
  _IMPORTDATABASEBACKUPMETADATA.fields_by_name['s3_bucket']._serialized_options = b'\350\3071\001'
  _EXPORTDATABASEBACKUPREQUEST.fields_by_name['cluster_id']._options = None
  _EXPORTDATABASEBACKUPREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _EXPORTDATABASEBACKUPREQUEST.fields_by_name['database_name']._options = None
  _EXPORTDATABASEBACKUPREQUEST.fields_by_name['database_name']._serialized_options = b'\350\3071\001'
  _EXPORTDATABASEBACKUPREQUEST.fields_by_name['s3_bucket']._options = None
  _EXPORTDATABASEBACKUPREQUEST.fields_by_name['s3_bucket']._serialized_options = b'\350\3071\001'
  _EXPORTDATABASEBACKUPMETADATA.fields_by_name['cluster_id']._options = None
  _EXPORTDATABASEBACKUPMETADATA.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _EXPORTDATABASEBACKUPMETADATA.fields_by_name['database_name']._options = None
  _EXPORTDATABASEBACKUPMETADATA.fields_by_name['database_name']._serialized_options = b'\350\3071\001'
  _EXPORTDATABASEBACKUPMETADATA.fields_by_name['s3_bucket']._options = None
  _EXPORTDATABASEBACKUPMETADATA.fields_by_name['s3_bucket']._serialized_options = b'\350\3071\001'
  _DATABASESERVICE.methods_by_name['Get']._options = None
  _DATABASESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002C\022A/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}'
  _DATABASESERVICE.methods_by_name['List']._options = None
  _DATABASESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\0023\0221/mdb/sqlserver/v1/clusters/{cluster_id}/databases'
  _DATABASESERVICE.methods_by_name['Create']._options = None
  _DATABASESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateDatabaseMetadata\022\010Database\202\323\344\223\0026\"1/mdb/sqlserver/v1/clusters/{cluster_id}/databases:\001*'
  _DATABASESERVICE.methods_by_name['Restore']._options = None
  _DATABASESERVICE.methods_by_name['Restore']._serialized_options = b'\262\322*#\n\027RestoreDatabaseMetadata\022\010Database\202\323\344\223\002>\"9/mdb/sqlserver/v1/clusters/{cluster_id}/databases:restore:\001*'
  _DATABASESERVICE.methods_by_name['ImportBackup']._options = None
  _DATABASESERVICE.methods_by_name['ImportBackup']._serialized_options = b'\262\322*(\n\034ImportDatabaseBackupMetadata\022\010Database\202\323\344\223\002=\"8/mdb/sqlserver/v1/clusters/{cluster_id}/databases:import:\001*'
  _DATABASESERVICE.methods_by_name['ExportBackup']._options = None
  _DATABASESERVICE.methods_by_name['ExportBackup']._serialized_options = b'\262\322*(\n\034ExportDatabaseBackupMetadata\022\010Database\202\323\344\223\002M\"H/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}:export:\001*'
  _DATABASESERVICE.methods_by_name['Delete']._options = None
  _DATABASESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteDatabaseMetadata\022\025google.protobuf.Empty\202\323\344\223\002C*A/mdb/sqlserver/v1/clusters/{cluster_id}/databases/{database_name}'
  _globals['_GETDATABASEREQUEST']._serialized_start=301
  _globals['_GETDATABASEREQUEST']._serialized_end=410
  _globals['_LISTDATABASESREQUEST']._serialized_start=412
  _globals['_LISTDATABASESREQUEST']._serialized_end=530
  _globals['_LISTDATABASESRESPONSE']._serialized_start=532
  _globals['_LISTDATABASESRESPONSE']._serialized_end=640
  _globals['_CREATEDATABASEREQUEST']._serialized_start=643
  _globals['_CREATEDATABASEREQUEST']._serialized_end=774
  _globals['_CREATEDATABASEMETADATA']._serialized_start=776
  _globals['_CREATEDATABASEMETADATA']._serialized_end=843
  _globals['_DELETEDATABASEREQUEST']._serialized_start=845
  _globals['_DELETEDATABASEREQUEST']._serialized_end=957
  _globals['_DELETEDATABASEMETADATA']._serialized_start=959
  _globals['_DELETEDATABASEMETADATA']._serialized_end=1026
  _globals['_RESTOREDATABASEREQUEST']._serialized_start=1029
  _globals['_RESTOREDATABASEREQUEST']._serialized_end=1224
  _globals['_RESTOREDATABASEMETADATA']._serialized_start=1227
  _globals['_RESTOREDATABASEMETADATA']._serialized_end=1361
  _globals['_IMPORTDATABASEBACKUPREQUEST']._serialized_start=1364
  _globals['_IMPORTDATABASEBACKUPREQUEST']._serialized_end=1519
  _globals['_IMPORTDATABASEBACKUPMETADATA']._serialized_start=1521
  _globals['_IMPORTDATABASEBACKUPMETADATA']._serialized_end=1648
  _globals['_EXPORTDATABASEBACKUPREQUEST']._serialized_start=1651
  _globals['_EXPORTDATABASEBACKUPREQUEST']._serialized_end=1801
  _globals['_EXPORTDATABASEBACKUPMETADATA']._serialized_start=1803
  _globals['_EXPORTDATABASEBACKUPMETADATA']._serialized_end=1930
  _globals['_DATABASESERVICE']._serialized_start=1933
  _globals['_DATABASESERVICE']._serialized_end=3403
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.apploadbalancer.v1.virtual_host_pb2
import yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class VirtualHostServiceStub:
    """A set of methods for managing virtual hosts of HTTP routers."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.GetVirtualHostRequest,
        yandex.cloud.apploadbalancer.v1.virtual_host_pb2.VirtualHost,
    ]
    """Returns the specified virtual host.

    To get the list of all virtual hosts of an HTTP router, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.ListVirtualHostsRequest,
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.ListVirtualHostsResponse,
    ]
    """Lists virtual hosts of the specified HTTP router."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.CreateVirtualHostRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a virtual host in the specified HTTP router."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.UpdateVirtualHostRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified virtual host of the specified HTTP router."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.DeleteVirtualHostRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified virtual host."""

    RemoveRoute: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.RemoveRouteRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified route from the specified virtual host."""

    UpdateRoute: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.UpdateRouteRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified route of the specified virtual host."""

class VirtualHostServiceAsyncStub:
    """A set of methods for managing virtual hosts of HTTP routers."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.GetVirtualHostRequest,
        yandex.cloud.apploadbalancer.v1.virtual_host_pb2.VirtualHost,
    ]
    """Returns the specified virtual host.

    To get the list of all virtual hosts of an HTTP router, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.ListVirtualHostsRequest,
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.ListVirtualHostsResponse,
    ]
    """Lists virtual hosts of the specified HTTP router."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.CreateVirtualHostRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a virtual host in the specified HTTP router."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.UpdateVirtualHostRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified virtual host of the specified HTTP router."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.DeleteVirtualHostRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified virtual host."""

    RemoveRoute: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.RemoveRouteRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified route from the specified virtual host."""

    UpdateRoute: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.UpdateRouteRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified route of the specified virtual host."""

class VirtualHostServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing virtual hosts of HTTP routers."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.GetVirtualHostRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.VirtualHost, collections.abc.Awaitable[yandex.cloud.apploadbalancer.v1.virtual_host_pb2.VirtualHost]]:
        """Returns the specified virtual host.

        To get the list of all virtual hosts of an HTTP router, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.ListVirtualHostsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.ListVirtualHostsResponse, collections.abc.Awaitable[yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.ListVirtualHostsResponse]]:
        """Lists virtual hosts of the specified HTTP router."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.CreateVirtualHostRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a virtual host in the specified HTTP router."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.UpdateVirtualHostRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified virtual host of the specified HTTP router."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.DeleteVirtualHostRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified virtual host."""

    @abc.abstractmethod
    def RemoveRoute(
        self,
        request: yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.RemoveRouteRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified route from the specified virtual host."""

    @abc.abstractmethod
    def UpdateRoute(
        self,
        request: yandex.cloud.apploadbalancer.v1.virtual_host_service_pb2.UpdateRouteRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified route of the specified virtual host."""

def add_VirtualHostServiceServicer_to_server(servicer: VirtualHostServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
